# tinySCPI
A Python library that enables the use of SCPI commands on the tinySA

## Dependency:
tinySCPI requires python >= 3.6, pyserial, pytest, and pytest-cov

```pip install pyserial```
```pip install pytest```
```pip install pytest-cov```

## Unit Test:
```pytest```

## Coverage:
```pytest --cov-config=.coveragerc --cov=tinyscpi tinyscpi/tests/ --cov-report html ```

## Contact Us:
Email: tinyscpi@vt.edu
